all.ChiValms<-function(){
     cat("\n")
     note_for_ChiValss_input()
     cat("\n")
     note_for_close_window()
     ChiValMSpar<-data.frame(subject=c(1,2),TBW=c(0),CBZ=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     ChiValMSpar<-edit(ChiValMSpar)
##     ChiValMSpar<-ymscheck(ChiValMSpar)
     cat("\n")
     ChiVal.ms(length(ChiValMSpar$subject),ChiValMSpar$c,ChiValMSpar$tau,ChiValMSpar$ts,ChiValMSpar$D,ChiValMSpar$TBW,ChiValMSpar$CBZ)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_ChiValss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-ChiValcpr(ChiValMSpar$D,ChiValMSpar$tau,ChiValMSpar$ts,ChiValMSpar$TBW)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-ChiValcpr(ChiValMSpar$D,ChiValMSpar$tau,ChiValMSpar$tau,ChiValMSpar$TBW)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}